[PATCH] tinycompress: rename crec usages

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The creord utility help listed crec as the utility name, change that to
crecord and also update the program explanation text.

Signed-off-by: Vinod Koul <vinod.koul@xxxxxxxxx>
---
 src/utils/crecord.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/utils/crecord.c b/src/utils/crecord.c
index 8d5b7b0b2c30..1ba54d70e89c 100644
--- a/src/utils/crecord.c
+++ b/src/utils/crecord.c
@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
  * crec command line recorder for compress audio record in alsa
  * Copyright (c) 2011-2012, Intel Corporation
  * Copyright (c) 2013-2014, Wolfson Microelectronic Ltd.
  * All rights reserved.
@@ -35,7 +35,7 @@
  *
  * LGPL LICENSE
  *
  * crec command line recorder for compress audio record in alsa
  * Copyright (c) 2011-2012, Intel Corporation
  * Copyright (c) 2013-2014, Wolfson Microelectronic Ltd.
  *
@@ -153,7 +153,7 @@ static void size_wave_header(struct wave_header *header, uint32_t size)
 
 static void usage(void)
 {
-	fprintf(stderr, "usage: crec [OPTIONS] [filename]\n"
+	fprintf(stderr, "usage: crecord [OPTIONS] [filename]\n"
 		"-c\tcard number\n"
 		"-d\tdevice node\n"
 		"-b\tbuffer size\n"
@@ -167,8 +167,8 @@ static void usage(void)
 		"If filename is not given the output is\n"
 		"written to stdout\n\n"
 		"Example:\n"
-		"\tcrec -c 1 -d 2 test.wav\n"
-		"\tcrec -f 5 test.wav\n",
+		"\tcrecord -c 1 -d 2 test.wav\n"
+		"\tcrecord -f 5 test.wav\n",
 		DEFAULT_CHANNELS, DEFAULT_RATE);
 
 	exit(EXIT_FAILURE);
@@ -1,7 +1,7 @@
  * BSD LICENSE
  *
- * crec command line recorder for compress audio record in alsa
+ * crecord command line recorder for compress audio record in alsa
  * Copyright (c) 2011-2012, Intel Corporation
  * Copyright (c) 2013-2014, Wolfson Microelectronic Ltd.
@@ -35,7 +35,7 @@
  * LGPL LICENSE
  *
- * crec command line recorder for compress audio record in alsa
+ * crecord command line recorder for compress audio record in alsa
  * Copyright (c) 2011-2012, Intel Corporation
  * Copyright (c) 2013-2014, Wolfson Microelectronic Ltd.
-- 
1.9.1

_______________________________________________
Alsa-devel mailing list
Alsa-devel@xxxxxxxxxxxxxxxx
http://mailman.alsa-project.org/mailman/listinfo/alsa-devel



[Index of Archives]     [ALSA User]     [Linux Audio Users]     [Kernel Archive]     [Asterisk PBX]     [Photo Sharing]     [Linux Sound]     [Video 4 Linux]     [Gimp]     [Yosemite News]

  Powered by Linux